# encoding=utf-8

from django.core.management.base import BaseCommand, CommandError
from django.db.utils import OperationalError

class Command(BaseCommand):
    help = 'DANGEROUS! Clear all django-tables after initial migrations to make loaddata work'

    def handle(self, *args, **options):
        clear_django_tables()


def clear_django_tables():
    was_error = False

    from django.contrib.auth.models import Permission
    try:
        Permission.objects.all().delete()
        print("Permission cleared")
    except OperationalError:
        print("No Permission table present")
        was_error = True

    from django.contrib.contenttypes.models import ContentType
    try:
        ContentType.objects.all().delete()
        print("ContentType cleared")
    except OperationalError:
        print("No ContentType table present")
        was_error = True

    if was_error:
        print("Probably, you need to call ./manage.py migrate first")



from setuptools import setup

setup(
    name='django-clear-tables',
    version='0.1.1',
    description='django manage.py task that clears the content of the django Permission and ContentTypes tables, '
                'after an initial migration, to make manage.py loaddata work.',
    long_description=open("./README.md").read(),
    long_description_content_type="text/markdown",
    url='https://github.com/defgsus/django-clear-tables',
    author='Stefan Berke',
    author_email='s.berke@netzkolchose.de',
    license='MIT',
    packages=['django_clear_tables', 'django_clear_tables.management.commands'],
    zip_safe=False,
)